@@ -10,43 +10,43 @@ function(para,...) {
     }
     type <- para$type
     if(type == 'cau') {
-      return(are.parcau.valid(para))
+      return(are.parcau.valid(para,...))
     }
     else if(type == 'exp') {
-      return(are.parexp.valid(para))
+      return(are.parexp.valid(para,...))
     }
     else if(type == 'gam') {
-      return(are.pargam.valid(para))
+      return(are.pargam.valid(para,...))
     }
     else if(type == 'gev') {
-      return(are.pargev.valid(para))
+      return(are.pargev.valid(para,...))
     }
     else if(type == 'gld') {
       return(are.pargld.valid(para,...))
     }    
     else if(type == 'glo') {
-      return(are.parglo.valid(para))
+      return(are.parglo.valid(para,...))
     }
     else if(type == 'gno') {
-      return(are.pargno.valid(para))
+      return(are.pargno.valid(para,...))
     }
     else if(type == 'gpa') {
-      return(are.pargpa.valid(para))
+      return(are.pargpa.valid(para,...))
     }
     else if(type == 'gum') {
-      return(are.pargum.valid(para))
+      return(are.pargum.valid(para,...))
     }
     else if(type == 'kap') {
-      return(are.parkap.valid(para))
+      return(are.parkap.valid(para,...))
     }
     else if(type == 'nor') {
-      return(are.parnor.valid(para))
+      return(are.parnor.valid(para,...))
     }
     else if(type == 'pe3') {
-      return(are.parpe3.valid(para))
+      return(are.parpe3.valid(para,...))
     }
     else if(type == 'wak') {
-      return(are.pareak.valid(para))
+      return(are.parwak.valid(para,...))
     }
     else {
       stop("Did not find a valid distribution type")
