@@ -41,7 +41,7 @@ function(para) {
       return(lmomwak(para))
     }
     else {
-      stop("Do not find a valid distribution type.")
+      stop("Did not find a valid distribution type")
     }
 }
 
