@@ -1,7 +1,7 @@
 "pargum" <-
 function(lmom) {
    euler <- 0.577215664901532861
-   para <- matrix(nrow = 2, ncol = 1);
+    para <- vector(mode="numeric", length=2)
    if(! are.lmom.valid(lmom)) {
      warning("L-moments are invalid.")
      return()
